import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:hangman/common/cubit/nav/nav_cubit_pages.dart';

import 'package:hangman/cubit/activity/activity_cubit.dart';
import 'package:hangman/ui/parameters/parameter_painter_difficulty_level.dart';

class ApplicationConfig {
  static const String parameterCodeGameMode = 'activity.gameMode';
  static const String parameterCodeGameLevel = 'activity.gameLevel';

  static const String gameModeValueOnline = 'online';
  static const String gameModeValueOffline = 'offline';

  static const String gameLevelValueEasy = 'easy';
  static const String gameLevelValueHard = 'hard';

  static final ApplicationConfigDefinition config = ApplicationConfigDefinition(
    appTitle: 'Hangman',
    activitySettings: [
      // game mode
      ApplicationSettingsParameter(
        code: parameterCodeGameMode,
        values: [
          ApplicationSettingsParameterItemValue(
            value: gameModeValueOnline,
            text: '🌐',
            color: Colors.teal,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: gameModeValueOffline,
            text: '📱',
            color: Colors.purple,
          ),
        ],
        builder: ({required context, required itemValue, required onPressed, required size}) {
          return StyledButton.icon(
            onPressed: onPressed,
            icon: Icon(itemValue.value == gameModeValueOnline
                ? UniconsLine.globe
                : UniconsLine.clipboard),
            color: itemValue.color ?? Colors.grey,
          );
        },
      ),

      // game level
      ApplicationSettingsParameter(
        code: parameterCodeGameLevel,
        values: [
          ApplicationSettingsParameterItemValue(
            value: gameLevelValueEasy,
            color: Colors.green,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: gameLevelValueHard,
            color: Colors.orange,
          ),
        ],
        customPainter: (context, value) => ParameterPainterDifficultyLevel(
          context: context,
          value: value,
        ),
      ),
    ],
    startNewActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).startNewActivity(context);
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
    deleteCurrentActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).deleteSavedActivity();
    },
    resumeActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).resumeSavedActivity();
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
  );
}
